@@ -1,3 +1,4 @@
+use std::collections::HashMap;
 use std::sync::Arc;
 use tokio::{
     io::Result,
@@ -6,20 +7,21 @@ use tokio::{
 
 use chamomile_types::{
     message::ReceiveMessage,
-    types::{new_io_error, PeerId},
+    types::{new_io_error, TransportType},
+    Peer, PeerId,
 };
 
 use crate::buffer::Buffer;
 use crate::kad::KadValue;
 use crate::keys::{Keypair, SessionKey};
-use crate::peer::Peer;
 use crate::peer_list::PeerList;
-use crate::transports::{RemotePublic, TransportSendMessage};
+use crate::transports::{start, RemotePublic, TransportRecvMessage, TransportSendMessage};
 
 pub(crate) struct Global {
     pub peer: Peer,
     pub key: Keypair,
-    pub transport_sender: Sender<TransportSendMessage>,
+    pub trans: Sender<TransportRecvMessage>,
+    pub transports: Arc<RwLock<HashMap<TransportType, Sender<TransportSendMessage>>>>,
     pub out_sender: Sender<ReceiveMessage>,
     pub peer_list: Arc<RwLock<PeerList>>,
     pub buffer: Arc<RwLock<Buffer>>,
@@ -30,7 +32,7 @@ pub(crate) struct Global {
 impl Global {
     #[inline]
     pub fn peer_id(&self) -> &PeerId {
-        self.peer.id()
+        &self.peer.id
     }
 
     #[inline]
@@ -67,11 +69,37 @@ impl Global {
     }
 
     #[inline]
-    pub async fn trans_send(&self, msg: TransportSendMessage) -> Result<()> {
-        self.transport_sender
-            .send(msg)
-            .await
-            .map_err(|_e| new_io_error("Transport missing"))
+    pub async fn trans_send(
+        &self,
+        trans_type: &TransportType,
+        msg: TransportSendMessage,
+    ) -> Result<()> {
+        let trans_lock = self.transports.read().await;
+        if let Some(sender) = trans_lock.get(trans_type) {
+            sender
+                .send(msg)
+                .await
+                .map_err(|_e| new_io_error("Transport missing"))
+        } else {
+            drop(trans_lock);
+            // start new transport to send it.
+            // Only TCP & QUIC
+            let main_send = self.trans.clone();
+            let mut new_peer = self.peer.clone();
+            new_peer.transport = *trans_type;
+            new_peer.zero_port();
+
+            let (_, trans_send, _, _) = start(&new_peer, Some(main_send)).await?;
+            trans_send
+                .send(msg)
+                .await
+                .map_err(|_e| new_io_error("Transport missing"))?;
+            self.transports
+                .write()
+                .await
+                .insert(*trans_type, trans_send);
+            Ok(())
+        }
     }
 
     #[inline]
